
DeNova Safecopy
---------------

Safecopy syncronizes drives and directories very carefully.
Rsync replacement that fixes rsync's fatal default metadata check.


Full Description
----------------

Learn more about the denova python package at:

    https://denova.com/open_source/safecopy/
